@@ -1,12 +1,12 @@
 package Perinci::Sub::Property::drops_privilege;
 
-use 5.010;
+use 5.010001;
 use strict;
 use warnings;
 
 use Perinci::Sub::PropertyUtil qw(declare_property);
 
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 declare_property(
     name => 'drops_privilege',
@@ -37,17 +37,19 @@ declare_property(
 1;
 # ABSTRACT: Declare that function drops privilege during running
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Perinci::Sub::Property::drops_privilege - Declare that function drops privilege during running
 
 =head1 VERSION
 
-version 0.06
+This document describes version 0.07 of Perinci::Sub::Property::drops_privilege (from Perl distribution Perinci-Sub-Property-drops_privilege), released on 2016-03-09.
 
 =head1 SYNOPSIS
 
@@ -68,20 +70,35 @@ dropped temporarily, make sure that we switch back to superuser. Sometimes when
 the function dies, privileges are not restored, causing failure to subsequent
 operation.
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Sub-Property-drops_privilege>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-Sub-Property-drops_privilege>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Sub-Property-drops_privilege>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 SEE ALSO
 
 L<Perinci>
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Steven Haryanto.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
